@@ -550,10 +550,14 @@ ts_s_includelist += sizeof *incnew;
     {
 	i386_32 = TRUE;
 	definestring("__AS386_32__");
+	definestring("__i386__");
     }
     else
 #endif
+    {
 	definestring("__AS386_16__");
+	definestring("__8086__");
+    }
 #endif
 #ifdef MC6809
     definestring("__AS09__");
@@ -796,7 +800,11 @@ PRIVATE void usage()
     fatalerror(
 #ifdef MC6809
 "usage: cc1 [-cdfptw[-]] [-Ddefine] [-Iincdir] [-Uundef] [-o outfile] [infile]");
-#else
+#else 
+#ifdef I80386
 "usage: cc1 [-03cdfltw[-]] [-Ddefine] [-Iincdir] [-Uundef] [-o outfile] [infile]");
+#else 
+"usage: cc1 [-cdfltw[-]] [-Ddefine] [-Iincdir] [-Uundef] [-o outfile] [infile]");
+#endif
 #endif
 }
